ConnectorServerHandler

Trait ConnectorServerHandler 

pub trait ConnectorServerHandler<___T: Transport = Channel> {
    // Required method
    fn connect(
        &mut self,
        request: Request<Connect, ___T>,
    ) -> impl Future<Output = ()> + Send;
}
A server handler for the Connector protocol.

See Connector for more details.

Required Methods

fn connect( &mut self, request: Request<Connect, ___T>, ) -> impl Future<Output = ()> + Send

Forward a server end of a protocol so that it can be connected.

  • request server the server end of the protocol to be served. The FIDL protocol that this speaks is determined out-of-band.
  • response This function has no response. The function is one-way to match the pipelining behaviors of other virtual filesystems.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors